@@ -1,7 +1,11 @@
-$TESTING=true
 $:.unshift File.join(File.dirname(__FILE__), '..', 'lib')
 require "rubygems"
 require "merb-core"
 require "merb-mailer"
 
-Merb.start :environment => 'test'
\ No newline at end of file
+Merb::Config.use do |c|
+  c[:session_store] = :memory
+end
+
+
+Merb.start :environment => 'test'
